@@ -492,7 +492,16 @@ class MultiSelectMixin:
         element_id = compute_and_register_element_id(
             widget_name,
             user_key=key,
-            form_id=form_id,
+            # Treat the provided key as the main identity. Only include
+            # changes to the options, accept_new_options, and max_selections
+            # in the identity computation as those can invalidate the
+            # current selection.
+            key_as_main_identity={
+                "options",
+                "max_selections",
+                "accept_new_options",
+                "format_func",
+            },
             dg=self.dg,
             label=label,
             options=formatted_options,
